@@ -83,7 +83,7 @@ class QuickDB:
         else:
             return pd.Series(result)
 
-    def getTradables(self, start, end=None):
+    def getTradables(self, start, end=None, tipsonly=False):
         """
         date에 거래정지, 정리매매 상태가 아닌 종목을 list로 반환.
         Args:
@@ -96,7 +96,13 @@ class QuickDB:
             end = start
         trdstp = self.getTS(88, start, end).replace({1:0, 0:1})
         liqsell = self.getTS(92, start, end).replace({1:0, 0:1})
-        return trdstp * liqsell
+        tradable = trdstp * liqsell
+        if not tipsonly:
+            return tradable
+        elif tipsonly:
+            idx = [tradable.index[0], tradable.index[-1]] 
+             return tradable.loc[idx]
+            
         # tradable = (trdstp * liqsell).where(lambda x : x == 1).dropna(axis=1)
         # if tradable.shape[0]:
         #     return tradable.columns.to_list()
